@@ -46,3 +46,19 @@
   )
   return(converted_chunk)
 }
+
+.readVlenUTF8 <- function(input) {
+  con <- rawConnection(input)
+  on.exit(close(con))
+  # Looking at numcodecs source code, this is by definition/convention
+  # always little-endian
+  nvalues <- readBin(con, what = "integer", n = 1, size = 4, endian = "little")
+  output <- character(length = nvalues)
+  for (i in seq_len(nvalues)) {
+    nbytes <- readBin(con, what = "integer", n = 1, size = 4, endian = "little")
+    output[i] <- readChar(con, nchars = nbytes, useBytes = TRUE)
+  }
+
+  Encoding(output) <- "UTF-8"
+  return(output)
+}
